@@ -9,12 +9,6 @@ use std::convert::TryInto;
 /// Prefer running queries from [Pool] unless there is a specific need for a single, continuous
 /// connection.
 pub trait Connection: Executor + Send + 'static {
-    /// Establish a new database connection.
-    fn open<T>(url: T) -> BoxFuture<'static, crate::Result<Self>>
-    where
-        T: TryInto<Url, Error = crate::Error>,
-        Self: Sized;
-
     /// Close this database connection.
     fn close(self) -> BoxFuture<'static, crate::Result<()>>;
 
@@ -23,3 +17,14 @@ pub trait Connection: Executor + Send + 'static {
         Box::pin(self.execute("SELECT 1", Default::default()).map_ok(|_| ()))
     }
 }
+
+/// Represents a type that can directly establish a new connection.
+pub trait Connect {
+    type Connection: Connection;
+
+    /// Establish a new database connection.
+    fn connect<T>(url: T) -> BoxFuture<'static, crate::Result<Self::Connection>>
+    where
+        T: TryInto<Url, Error = crate::Error>,
+        Self: Sized;
+}
