@@ -1,14 +1,11 @@
 //! **Postgres** database and connection types.
 
-use std::convert::TryInto;
-
 pub use arguments::PgArguments;
 pub use connection::PgConnection;
 pub use database::Postgres;
 pub use error::PgError;
 pub use row::PgRow;
-
-use crate::url::Url;
+pub use types::PgTypeInfo;
 
 mod arguments;
 mod connection;
@@ -20,13 +17,4 @@ mod row;
 mod types;
 
 /// An alias for [`Pool`], specialized for **Postgres**.
-pub type PgPool = super::Pool<Postgres>;
-
-// used in tests and hidden code in examples
-#[doc(hidden)]
-pub async fn connect<T>(url: T) -> crate::Result<PgConnection>
-where
-    T: TryInto<Url, Error = crate::Error>,
-{
-    PgConnection::open(url.try_into()).await
-}
+pub type PgPool = super::Pool<PgConnection>;
