@@ -1,3 +1,4 @@
+use std::borrow::Cow;
 use std::convert::{TryFrom, TryInto};
 
 pub struct Url(url::Url);
@@ -64,4 +65,10 @@ impl Url {
             Some(database)
         }
     }
+
+    pub fn get_param(&self, key: &str) -> Option<Cow<str>> {
+        self.0
+            .query_pairs()
+            .find_map(|(key_, val)| if key == key_ { Some(val) } else { None })
+    }
 }
